@@ -988,9 +988,13 @@ static Image *ReadPATTERNImage(const ImageInfo *image_info,
         Tile pattern across image canvas.
       */
       pattern_image=image;
-      image=AcquireImage(blob_info);
-      image->background_color=pattern_image->background_color;
-      (void) SetImageBackgroundColor(image);
+      image=CloneImage(pattern_image,0,0,MagickTrue,exception);
+      (void) ParseAbsoluteGeometry(image_info->size,&image->extract_info);
+      image->columns=image->extract_info.width;
+      image->rows=image->extract_info.height;
+      image->offset=image->extract_info.x;
+      image->extract_info.x=0;
+      image->extract_info.y=0;
       (void) TextureImage(image,pattern_image);
       pattern_image=DestroyImage(pattern_image);
     }
