@@ -17,7 +17,7 @@
 %                               November 2001                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,6 +52,7 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/pixel.h"
 #include "magick/quantize.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
@@ -119,6 +120,9 @@ typedef struct
   size_t
     file_size;
 
+  size_t
+    number_layers;
+
   ExceptionInfo
     *exception;
 } XCFDocInfo;
@@ -135,7 +139,7 @@ typedef struct
     width,
     height,
     type,
-    opacity,
+    alpha,
     visible,
     linked,
     preserve_trans,
@@ -165,7 +169,7 @@ typedef struct
     red,
     green,
     blue,
-    opacity;
+    alpha;
 } XCFPixelPacket;
 
 /*
@@ -366,18 +370,18 @@ static MagickBooleanType load_tile(Image *image,Image *tile_image,
   exception=(&image->exception);
   for (y=0; y < (ssize_t) tile_image->rows; y++)
   {
-    q=QueueAuthenticPixels(tile_image,0,y,tile_image->columns,1,exception);
+    q=GetAuthenticPixels(tile_image,0,y,tile_image->columns,1,exception);
     if (q == (PixelPacket *) NULL)
       break;
     if (inDocInfo->image_type == GIMP_GRAY)
       {
         for (x=0; x < (ssize_t) tile_image->columns; x++)
         {
-          q->red=ScaleCharToQuantum(*graydata);
-          q->green=q->red;
-          q->blue=q->red;
-          q->opacity=ScaleCharToQuantum((unsigned char) (255-
-            inLayerInfo->opacity));
+          SetPixelRed(q,ScaleCharToQuantum(*graydata));
+          SetPixelGreen(q,GetPixelRed(q));
+          SetPixelBlue(q,GetPixelRed(q));
+          SetPixelAlpha(q,ScaleCharToQuantum((unsigned char)
+            inLayerInfo->alpha));
           graydata++;
           q++;
         }
@@ -387,11 +391,11 @@ static MagickBooleanType load_tile(Image *image,Image *tile_image,
         {
           for (x=0; x < (ssize_t) tile_image->columns; x++)
           {
-            q->red=ScaleCharToQuantum(xcfdata->red);
-            q->green=ScaleCharToQuantum(xcfdata->green);
-            q->blue=ScaleCharToQuantum(xcfdata->blue);
-            q->opacity=(Quantum) (xcfdata->opacity == 0U ? TransparentOpacity :
-              ScaleCharToQuantum((unsigned char) (255-inLayerInfo->opacity)));
+            SetPixelRed(q,ScaleCharToQuantum(xcfdata->red));
+            SetPixelGreen(q,ScaleCharToQuantum(xcfdata->green));
+            SetPixelBlue(q,ScaleCharToQuantum(xcfdata->blue));
+            SetPixelAlpha(q,xcfdata->alpha == 255U ? TransparentOpacity :
+              ScaleCharToQuantum((unsigned char) inLayerInfo->alpha));
             xcfdata++;
             q++;
           }
@@ -409,23 +413,24 @@ static MagickBooleanType load_tile_rle(Image *image,Image *tile_image,
   ExceptionInfo
     *exception;
 
-  ssize_t
-    i,
-    j;
-
   MagickOffsetType
     size;
 
+  Quantum
+    alpha;
+
   register PixelPacket
     *q;
 
-  ssize_t
-    bytes_per_pixel,
-    count;
-
   size_t
     length;
 
+  ssize_t
+    bytes_per_pixel,
+    count,
+    i,
+    j;
+
   unsigned char
     data,
     pixel,
@@ -442,10 +447,13 @@ static MagickBooleanType load_tile_rle(Image *image,Image *tile_image,
   count=ReadBlob(image, (size_t) data_length, xcfdata);
   xcfdatalimit = xcfodata+count-1;
   exception=(&image->exception);
+  alpha=ScaleCharToQuantum((unsigned char) inLayerInfo->alpha);
   for (i=0; i < (ssize_t) bytes_per_pixel; i++)
   {
     q=GetAuthenticPixels(tile_image,0,0,tile_image->columns,tile_image->rows,
       exception);
+    if (q == (PixelPacket *) NULL)
+      continue;
     size=(MagickOffsetType) tile_image->rows*tile_image->columns;
     while (size > 0)
     {
@@ -475,38 +483,37 @@ static MagickBooleanType load_tile_rle(Image *image,Image *tile_image,
               {
                 case 0:
                 {
-                  q->red=ScaleCharToQuantum(data);
-                  if (inDocInfo->image_type == GIMP_GRAY)
+                  SetPixelRed(q,ScaleCharToQuantum(data));
+                  if (inDocInfo->image_type != GIMP_GRAY)
                     {
-                      q->green=ScaleCharToQuantum(data);
-                      q->blue=ScaleCharToQuantum(data);
-                      q->opacity=ScaleCharToQuantum((unsigned char) (255-
-                        inLayerInfo->opacity));
+                      SetPixelGreen(q,ScaleCharToQuantum(data));
+                      SetPixelBlue(q,ScaleCharToQuantum(data));
+                      SetPixelAlpha(q,data == 255U ? alpha :
+                        ScaleCharToQuantum(data));
                     }
                   else
                     {
-                      q->green= q->red;
-                      q->blue= q->red;
-                      q->opacity=ScaleCharToQuantum((unsigned char) (255-
-                        inLayerInfo->opacity));
+                      SetPixelGreen(q,GetPixelRed(q));
+                      SetPixelBlue(q,GetPixelRed(q));
+                      SetPixelAlpha(q,data == 255U ? alpha :
+                        ScaleCharToQuantum(data));
                     }
                   break;
                 }
                 case 1:
                 {
-                  q->green=ScaleCharToQuantum(data);
+                  SetPixelGreen(q,ScaleCharToQuantum(data));
                   break;
                 }
                 case 2:
                 {
-                  q->blue=ScaleCharToQuantum(data);
+                  SetPixelBlue(q,ScaleCharToQuantum(data));
                   break;
                 }
                 case 3:
                 {
-                  q->opacity=(Quantum) (data == 0 ? TransparentOpacity :
-                    ScaleCharToQuantum((unsigned char) (255-
-                    inLayerInfo->opacity)));
+                  SetPixelAlpha(q,data == 255U ? alpha :
+                    ScaleCharToQuantum(data));
                   break;
                 }
               }
@@ -529,45 +536,44 @@ static MagickBooleanType load_tile_rle(Image *image,Image *tile_image,
             if (xcfdata > xcfdatalimit)
               goto bogus_rle;
             pixel=(*xcfdata++);
-            for (j= 0; j < (ssize_t) length; j++)
+            for (j=0; j < (ssize_t) length; j++)
             {
               data=pixel;
               switch (i)
               {
                 case 0:
                 {
-                  q->red=ScaleCharToQuantum(data);
-                  if (inDocInfo->image_type == GIMP_GRAY)
+                  SetPixelRed(q,ScaleCharToQuantum(data));
+                  if (inDocInfo->image_type != GIMP_GRAY)
                     {
-                      q->green=ScaleCharToQuantum(data);
-                      q->blue=ScaleCharToQuantum(data);
-                      q->opacity=ScaleCharToQuantum((unsigned char) (255-
-                        inLayerInfo->opacity));
+                      SetPixelGreen(q,ScaleCharToQuantum(data));
+                      SetPixelBlue(q,ScaleCharToQuantum(data));
+                      SetPixelAlpha(q,data == 255U ? alpha :
+                        ScaleCharToQuantum(data));
                     }
                   else
                     {
-                      q->green=q->red;
-                      q->blue=q->red;
-                      q->opacity=ScaleCharToQuantum((unsigned char) (255-
-                        inLayerInfo->opacity));
+                      SetPixelGreen(q,GetPixelRed(q));
+                      SetPixelBlue(q,GetPixelRed(q));
+                      SetPixelAlpha(q,data == 255U ? alpha :
+                        ScaleCharToQuantum(data));
                     }
                   break;
                 }
                 case 1:
                 {
-                  q->green=ScaleCharToQuantum(data);
+                  SetPixelGreen(q,ScaleCharToQuantum(data));
                   break;
                 }
                 case 2:
                 {
-                  q->blue=ScaleCharToQuantum(data);
+                  SetPixelBlue(q,ScaleCharToQuantum(data));
                   break;
                 }
                 case 3:
                 {
-                  q->opacity=(Quantum) (data == 0 ? TransparentOpacity :
-                    ScaleCharToQuantum((unsigned char) (255-
-                    inLayerInfo->opacity)));
+                  SetPixelAlpha(q,data == 255U ? alpha :
+                    ScaleCharToQuantum(data));
                   break;
                 }
               }
@@ -625,15 +631,16 @@ static MagickBooleanType load_level(Image *image,XCFDocInfo *inDocInfo,
   width=ReadBlobMSBLong(image);
   height=ReadBlobMSBLong(image);
 
-  /* read in the first tile offset.
-   *  if it is '0', then this tile level is empty
-   *  and we can simply return.
-   */
+  /*
+    Read in the first tile offset.  If it is '0', then this tile level is empty
+    and we can simply return.
+  */
   offset=(MagickOffsetType) ReadBlobMSBLong(image);
   if (offset == 0)
     return(MagickTrue);
-  /* Initialise the reference for the in-memory tile-compression
-   */
+  /*
+    Initialize the reference for the in-memory tile-compression.
+  */
   ntile_rows=(height+TILE_HEIGHT-1)/TILE_HEIGHT;
   ntile_cols=(width+TILE_WIDTH-1)/TILE_WIDTH;
   ntiles=ntile_rows*ntile_cols;
@@ -661,10 +668,12 @@ static MagickBooleanType load_level(Image *image,XCFDocInfo *inDocInfo,
       */
       tile_image_width=(size_t) (destLeft == (int) ntile_cols-1 ?
         (int) width % TILE_WIDTH : TILE_WIDTH);
-      if (tile_image_width == 0) tile_image_width=TILE_WIDTH;
+      if (tile_image_width == 0)
+        tile_image_width=TILE_WIDTH;
       tile_image_height = (size_t) (destTop == (int) ntile_rows-1 ?
         (int) height % TILE_HEIGHT : TILE_HEIGHT);
-      if (tile_image_height == 0) tile_image_height=TILE_HEIGHT;
+      if (tile_image_height == 0)
+        tile_image_height=TILE_HEIGHT;
       tile_image=CloneImage(inLayerInfo->image,tile_image_width,
         tile_image_height,MagickTrue,exception);
 
@@ -728,8 +737,11 @@ static MagickBooleanType load_hierarchy(Image *image,XCFDocInfo *inDocInfo,
     bytes_per_pixel;
 
   width=ReadBlobMSBLong(image);
+  (void) width;
   height=ReadBlobMSBLong(image);
+  (void) height;
   bytes_per_pixel=inDocInfo->bytes_per_pixel=ReadBlobMSBLong(image);
+  (void) bytes_per_pixel;
 
   /* load in the levels...we make sure that the number of levels
    *  calculated when the TileManager was created is the same
@@ -763,8 +775,8 @@ static MagickBooleanType load_hierarchy(Image *image,XCFDocInfo *inDocInfo,
   return(MagickTrue);
 }
 
-static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
-  XCFLayerInfo *outLayer )
+static MagickBooleanType ReadOneLayer(const ImageInfo *image_info,Image* image,
+  XCFDocInfo* inDocInfo,XCFLayerInfo *outLayer,const ssize_t layer)
 {
   MagickOffsetType
     offset;
@@ -784,11 +796,6 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
   outLayer->type = ReadBlobMSBLong(image);
   (void) ReadBlobStringWithLongSize(image, outLayer->name,
     sizeof(outLayer->name));
-  /* allocate the image for this layer */
-  outLayer->image=CloneImage(image,outLayer->width, outLayer->height,MagickTrue,
-     &image->exception);
-  if (outLayer->image == (Image *) NULL)
-    return MagickFalse;
   /* read the layer properties! */
   foundPropEnd = 0;
   while ( (foundPropEnd == MagickFalse) && (EOFBlob(image) == MagickFalse) ) {
@@ -806,7 +813,7 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
       outLayer->floating_offset = ReadBlobMSBLong(image);
       break;
     case PROP_OPACITY:
-      outLayer->opacity = ReadBlobMSBLong(image);
+      outLayer->alpha = ReadBlobMSBLong(image);
       break;
     case PROP_VISIBLE:
       outLayer->visible = ReadBlobMSBLong(image);
@@ -881,11 +888,39 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
 
   if (foundPropEnd == MagickFalse)
     return(MagickFalse);
+  /* allocate the image for this layer */
+  if (image_info->number_scenes != 0)
+    {
+      ssize_t
+        scene;
+
+      scene=inDocInfo->number_layers-layer-1;
+      if (scene > (image_info->scene+image_info->number_scenes-1))
+        {
+          outLayer->image=CloneImage(image,0,0,MagickTrue,&image->exception);
+          if (outLayer->image == (Image *) NULL)
+            return(MagickFalse);
+          outLayer->image->page.x=outLayer->offset_x;
+          outLayer->image->page.y=outLayer->offset_y;
+          outLayer->image->page.width=outLayer->width;
+          outLayer->image->page.height=outLayer->height;
+          return(MagickTrue);
+        }
+    }
+  /* allocate the image for this layer */
+  outLayer->image=CloneImage(image,outLayer->width, outLayer->height,MagickTrue,
+     &image->exception);
+  if (outLayer->image == (Image *) NULL)
+    return(MagickFalse);
   /* clear the image based on the layer opacity */
   outLayer->image->background_color.opacity=
-    ScaleCharToQuantum((unsigned char) (255-outLayer->opacity));    
+    ScaleCharToQuantum((unsigned char) (255-outLayer->alpha));    
   (void) SetImageBackgroundColor(outLayer->image);
 
+  outLayer->image->page.x=outLayer->offset_x;
+  outLayer->image->page.y=outLayer->offset_y;
+  outLayer->image->page.width=outLayer->width;
+  outLayer->image->page.height=outLayer->height;
   /* set the compositing mode */
   outLayer->image->compose = GIMPBlendModeToCompositeOperator( outLayer->mode );
   if ( outLayer->visible == MagickFalse )
@@ -967,7 +1002,6 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -990,14 +1024,12 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     i;
 
   size_t
+    image_type,
     length;
 
   ssize_t
     count;
 
-  size_t
-    image_type;
-
   XCFDocInfo
     doc_info;
 
@@ -1046,7 +1078,6 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     else
       if (image_type == GIMP_INDEXED)
         ThrowReaderException(CoderError,"ColormapTypeNotSupported");
-  (void) SetImageBackgroundColor(image);
   image->matte=MagickTrue;
   /*
     Read properties.
@@ -1262,6 +1293,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           }
     } while (foundAllLayers == MagickFalse);
+    doc_info.number_layers=number_layers;
     offset=SeekBlob(image,oldPos,SEEK_SET); /* restore the position! */
     if (offset < 0)
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
@@ -1295,15 +1327,17 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       /* seek to the layer offset */
       offset=SeekBlob(image,offset,SEEK_SET);
       /* read in the layer */
-      layer_ok=ReadOneLayer(image,&doc_info,&layer_info[current_layer]);
+      layer_ok=ReadOneLayer(image_info,image,&doc_info,
+        &layer_info[current_layer],current_layer);
       if (layer_ok == MagickFalse)
         {
           int j;
 
           for (j=0; j < current_layer; j++)
             layer_info[j].image=DestroyImage(layer_info[j].image);
-        ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-      }
+          layer_info=(XCFLayerInfo *) RelinquishMagickMemory(layer_info);
+          ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+        }
       /* restore the saved position so we'll be ready to
       *  read the next offset.
       */
@@ -1333,7 +1367,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
                      layer_info[j].offset_x, layer_info[j].offset_y );
              layer_info[j].image =DestroyImage( layer_info[j].image );
 
-            /* Bob says that if we do this, we'll get REAL gray images! */
+            /* If we do this, we'll get REAL gray images! */
             if ( image_type == GIMP_GRAY ) {
               QuantizeInfo  qi;
               GetQuantizeInfo(&qi);
@@ -1346,37 +1380,21 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #else
       {
         /* NOTE: XCF layers are REVERSED from composite order! */
-        signed int  j;
+        ssize_t  j;
 
         /* first we copy the last layer on top of the main image */
         (void) CompositeImage(image,CopyCompositeOp,
           layer_info[number_layers-1].image,
           layer_info[number_layers-1].offset_x,
           layer_info[number_layers-1].offset_y);
-          layer_info[number_layers-1].image=DestroyImage(
-            layer_info[number_layers-1].image);
+        layer_info[number_layers-1].image=DestroyImage(
+          layer_info[number_layers-1].image);
 
         /* now reverse the order of the layers as they are put
            into subimages
         */
-        j=number_layers-2;
-        image->next=layer_info[j].image;
-        layer_info[j].image->previous=image;
-        layer_info[j].image->page.x=layer_info[j].offset_x;
-        layer_info[j].image->page.y=layer_info[j].offset_y;
-        layer_info[j].image->page.width=layer_info[j].width;
-        layer_info[j].image->page.height=layer_info[j].height;
-        for (j=number_layers-3; j>=0; j--)
-        {
-          if (j > 0)
-            layer_info[j].image->next=layer_info[j-1].image;
-          if (j < (number_layers-1))
-            layer_info[j].image->previous=layer_info[j+1].image;
-          layer_info[j].image->page.x=layer_info[j].offset_x;
-          layer_info[j].image->page.y=layer_info[j].offset_y;
-          layer_info[j].image->page.width=layer_info[j].width;
-          layer_info[j].image->page.height=layer_info[j].height;
-        }
+        for (j=(long) number_layers-2; j >= 0; j--)
+          AppendImageToList(&image,layer_info[j].image);
       }
 #endif
     }
