@@ -16,7 +16,7 @@
 %                               March  2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -559,12 +559,6 @@ MagickExport MagickBooleanType PasskeyDecipherImage(Image *image,
   const unsigned char
     *digest;
 
-  IndexPacket
-    *indexes;
-
-  ssize_t
-    y;
-
   MagickBooleanType
     proceed;
 
@@ -583,6 +577,9 @@ MagickExport MagickBooleanType PasskeyDecipherImage(Image *image,
   size_t
     length;
 
+  ssize_t
+    y;
+
   StringInfo
     *key,
     *nonce;
@@ -656,7 +653,6 @@ MagickExport MagickBooleanType PasskeyDecipherImage(Image *image,
     q=GetCacheViewAuthenticPixels(image_view,0,y,image->columns,1,exception);
     if (q == (PixelPacket *) NULL)
       break;
-    indexes=GetCacheViewAuthenticIndexQueue(image_view);
     length=ExportQuantumPixels(image,image_view,quantum_info,quantum_type,
       pixels,exception);
     p=pixels;
@@ -762,12 +758,6 @@ MagickExport MagickBooleanType PasskeyEncipherImage(Image *image,
   const unsigned char
     *digest;
 
-  IndexPacket
-    *indexes;
-
-  ssize_t
-    y;
-
   MagickBooleanType
     proceed;
 
@@ -786,6 +776,9 @@ MagickExport MagickBooleanType PasskeyEncipherImage(Image *image,
   size_t
     length;
 
+  ssize_t
+    y;
+
   StringInfo
     *key,
     *nonce;
@@ -866,7 +859,6 @@ MagickExport MagickBooleanType PasskeyEncipherImage(Image *image,
     q=GetCacheViewAuthenticPixels(image_view,0,y,image->columns,1,exception);
     if (q == (PixelPacket *) NULL)
       break;
-    indexes=GetCacheViewAuthenticIndexQueue(image_view);
     length=ExportQuantumPixels(image,image_view,quantum_info,quantum_type,
       pixels,exception);
     p=pixels;
@@ -964,13 +956,13 @@ static inline unsigned int RotateRight(const unsigned int x)
 
 static void SetAESKey(AESInfo *aes_info,const StringInfo *key)
 {
+  register ssize_t
+    i;
+
   ssize_t
     bytes,
     n;
 
-  register ssize_t
-    i;
-
   unsigned char
     *datum;
 
