@@ -66,8 +66,7 @@ static inline MagickBooleanType IsGrayColorspace(
   return(MagickFalse);
 }
 
-static inline MagickBooleanType IsRGBColorspace(
-  const ColorspaceType colorspace)
+static inline MagickBooleanType IsRGBColorspace(const ColorspaceType colorspace)
 {
   if ((IsGrayColorspace(colorspace) != MagickFalse) ||
       (colorspace == RGBColorspace) || (colorspace == sRGBColorspace) ||
