@@ -17,7 +17,7 @@
 %                                   July 1992                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -225,8 +225,9 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
       frame_image=DestroyImage(frame_image);
       return((Image *) NULL);
     }
-  if (frame_image->matte_color.opacity != OpaqueOpacity)
-    frame_image->matte=MagickTrue;
+  if ((frame_image->border_color.opacity != OpaqueOpacity) &&
+      (frame_image->matte == MagickFalse))
+    (void) SetImageAlphaChannel(frame_image,OpaqueAlphaChannel);
   frame_image->page=image->page;
   if ((image->page.width != 0) && (image->page.height != 0))
     {
@@ -403,7 +404,7 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
     Draw sides of ornamental border.
   */
 #if defined(MAGICKCORE_OPENMP_SUPPORT) 
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status) omp_throttle(1)
+  #pragma omp parallel for schedule(static) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
@@ -510,7 +511,7 @@ MagickExport Image *FrameImage(const Image *image,const FrameInfo *frame_info,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT) 
-  #pragma omp critical (MagickCore_FrameImage)
+        #pragma omp critical (MagickCore_FrameImage)
 #endif
         proceed=SetImageProgress(image,FrameImageTag,progress++,image->rows);
         if (proceed == MagickFalse)
@@ -727,7 +728,7 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
   exception=(&image->exception);
   image_view=AcquireCacheView(image);
 #if defined(MAGICKCORE_OPENMP_SUPPORT) 
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status) omp_throttle(1)
+  #pragma omp parallel for schedule(static) shared(progress,status)
 #endif
   for (y=0; y < (ssize_t) raise_info->height; y++)
   {
@@ -747,38 +748,41 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
       }
     for (x=0; x < y; x++)
     {
-      q->red=ClampToQuantum(QuantumScale*((MagickRealType) q->red*
-        HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor)));
-      q->green=ClampToQuantum(QuantumScale*((MagickRealType) q->green*
-        HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor)));
-      q->blue=ClampToQuantum(QuantumScale*((MagickRealType) q->blue*
-        HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor)));
+      SetPixelRed(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelRed(q)*HighlightFactor+(MagickRealType) foreground*
+        (QuantumRange-HighlightFactor))));
+      SetPixelGreen(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelGreen(q)*HighlightFactor+(MagickRealType) foreground*
+        (QuantumRange-HighlightFactor))));
+      SetPixelBlue(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelBlue(q)*HighlightFactor+(MagickRealType) foreground*
+        (QuantumRange-HighlightFactor))));
       q++;
     }
     for ( ; x < (ssize_t) (image->columns-y); x++)
     {
-      q->red=ClampToQuantum(QuantumScale*((MagickRealType) q->red*
-        AccentuateFactor+(MagickRealType) foreground*(QuantumRange-
-        AccentuateFactor)));
-      q->green=ClampToQuantum(QuantumScale*((MagickRealType) q->green*
-        AccentuateFactor+(MagickRealType) foreground*(QuantumRange-
-        AccentuateFactor)));
-      q->blue=ClampToQuantum(QuantumScale*((MagickRealType) q->blue*
-        AccentuateFactor+(MagickRealType) foreground*(QuantumRange-
-        AccentuateFactor)));
+      SetPixelRed(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelRed(q)*AccentuateFactor+(MagickRealType) foreground*
+        (QuantumRange-AccentuateFactor))));
+      SetPixelGreen(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelGreen(q)*AccentuateFactor+(MagickRealType) foreground*
+        (QuantumRange-AccentuateFactor))));
+      SetPixelBlue(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelBlue(q)*AccentuateFactor+(MagickRealType) foreground*
+        (QuantumRange-AccentuateFactor))));
       q++;
     }
     for ( ; x < (ssize_t) image->columns; x++)
     {
-      q->red=ClampToQuantum(QuantumScale*((MagickRealType) q->red*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor)));
-      q->green=ClampToQuantum(QuantumScale*((MagickRealType) q->green*
-        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
-      q->blue=ClampToQuantum(QuantumScale*((MagickRealType) q->blue*
-        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
+      SetPixelRed(q,ClampToQuantum(QuantumScale*((MagickRealType) 
+        GetPixelRed(q)*ShadowFactor+(MagickRealType) background*
+        (QuantumRange-ShadowFactor))));
+      SetPixelGreen(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelGreen(q)*ShadowFactor+(MagickRealType) background*
+        (QuantumRange-ShadowFactor))));
+      SetPixelBlue(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelBlue(q)*ShadowFactor+(MagickRealType) background*
+        (QuantumRange-ShadowFactor))));
       q++;
     }
     if (SyncCacheViewAuthenticPixels(image_view,exception) == MagickFalse)
@@ -794,7 +798,7 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
       }
   }
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status) omp_throttle(1)
+  #pragma omp parallel for schedule(static) shared(progress,status)
 #endif
   for (y=(ssize_t) raise_info->height; y < (ssize_t) (image->rows-raise_info->height); y++)
   {
@@ -814,27 +818,30 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
       }
     for (x=0; x < (ssize_t) raise_info->width; x++)
     {
-      q->red=ClampToQuantum(QuantumScale*((MagickRealType) q->red*
-        HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor)));
-      q->green=ClampToQuantum(QuantumScale*((MagickRealType) q->green*
-        HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor)));
-      q->blue=ClampToQuantum(QuantumScale*((MagickRealType) q->blue*
-        HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor)));
+      SetPixelRed(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelRed(q)*HighlightFactor+(MagickRealType) foreground*
+        (QuantumRange-HighlightFactor))));
+      SetPixelGreen(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelGreen(q)*HighlightFactor+(MagickRealType) foreground*
+        (QuantumRange-HighlightFactor))));
+      SetPixelBlue(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelBlue(q)*HighlightFactor+(MagickRealType) foreground*
+        (QuantumRange-HighlightFactor))));
       q++;
     }
     for ( ; x < (ssize_t) (image->columns-raise_info->width); x++)
       q++;
     for ( ; x < (ssize_t) image->columns; x++)
     {
-      q->red=ClampToQuantum(QuantumScale*((MagickRealType) q->red*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor)));
-      q->green=ClampToQuantum(QuantumScale*((MagickRealType) q->green*
-        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
-      q->blue=ClampToQuantum(QuantumScale*((MagickRealType) q->blue*
-        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
+      SetPixelRed(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelRed(q)*ShadowFactor+(MagickRealType) background*
+        (QuantumRange-ShadowFactor))));
+      SetPixelGreen(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelGreen(q)*ShadowFactor+(MagickRealType) background*
+        (QuantumRange-ShadowFactor))));
+      SetPixelBlue(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelBlue(q)*ShadowFactor+(MagickRealType) background*
+        (QuantumRange-ShadowFactor))));
       q++;
     }
     if (SyncCacheViewAuthenticPixels(image_view,exception) == MagickFalse)
@@ -850,7 +857,7 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
       }
   }
 #if defined(MAGICKCORE_OPENMP_SUPPORT) 
-  #pragma omp parallel for schedule(dynamic,4) shared(progress,status) omp_throttle(1)
+  #pragma omp parallel for schedule(static) shared(progress,status)
 #endif
   for (y=(ssize_t) (image->rows-raise_info->height); y < (ssize_t) image->rows; y++)
   {
@@ -870,35 +877,41 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
       }
     for (x=0; x < (ssize_t) (image->rows-y); x++)
     {
-      q->red=ClampToQuantum(QuantumScale*((MagickRealType) q->red*
-        HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor)));
-      q->green=ClampToQuantum(QuantumScale*((MagickRealType) q->green*
-        HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor)));
-      q->blue=ClampToQuantum(QuantumScale*((MagickRealType) q->blue*
-        HighlightFactor+(MagickRealType) foreground*(QuantumRange-
-        HighlightFactor)));
+      SetPixelRed(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelRed(q)*HighlightFactor+(MagickRealType) foreground*
+        (QuantumRange-HighlightFactor))));
+      SetPixelGreen(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelGreen(q)*HighlightFactor+(MagickRealType) foreground*
+        (QuantumRange-HighlightFactor))));
+      SetPixelBlue(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelBlue(q)*HighlightFactor+(MagickRealType) foreground*
+        (QuantumRange-HighlightFactor))));
       q++;
     }
     for ( ; x < (ssize_t) (image->columns-(image->rows-y)); x++)
     {
-      q->red=ClampToQuantum(QuantumScale*((MagickRealType) q->red*TroughFactor+
-        (MagickRealType) background*(QuantumRange-TroughFactor)));
-      q->green=ClampToQuantum(QuantumScale*((MagickRealType) q->green*
-        TroughFactor+(MagickRealType) background*(QuantumRange-TroughFactor)));
-      q->blue=ClampToQuantum(QuantumScale*((MagickRealType) q->blue*
-        TroughFactor+(MagickRealType) background*(QuantumRange-TroughFactor)));
+      SetPixelRed(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelRed(q)*TroughFactor+(MagickRealType) background*
+        (QuantumRange-TroughFactor))));
+      SetPixelGreen(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelGreen(q)*TroughFactor+(MagickRealType) background*
+        (QuantumRange-TroughFactor))));
+      SetPixelBlue(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelBlue(q)*TroughFactor+(MagickRealType) background*
+        (QuantumRange-TroughFactor))));
       q++;
     }
     for ( ; x < (ssize_t) image->columns; x++)
     {
-      q->red=ClampToQuantum(QuantumScale*((MagickRealType) q->red*ShadowFactor+
-        (MagickRealType) background*(QuantumRange-ShadowFactor)));
-      q->green=ClampToQuantum(QuantumScale*((MagickRealType) q->green*
-        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
-      q->blue=ClampToQuantum(QuantumScale*((MagickRealType) q->blue*
-        ShadowFactor+(MagickRealType) background*(QuantumRange-ShadowFactor)));
+      SetPixelRed(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelRed(q)*ShadowFactor+(MagickRealType) background*
+        (QuantumRange-ShadowFactor))));
+      SetPixelGreen(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelGreen(q)*ShadowFactor+(MagickRealType) background*
+        (QuantumRange-ShadowFactor))));
+      SetPixelBlue(q,ClampToQuantum(QuantumScale*((MagickRealType)
+        GetPixelBlue(q)*ShadowFactor+(MagickRealType) background*
+        (QuantumRange-ShadowFactor))));
       q++;
     }
     if (SyncCacheViewAuthenticPixels(image_view,exception) == MagickFalse)
@@ -909,7 +922,7 @@ MagickExport MagickBooleanType RaiseImage(Image *image,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp critical (MagickCore_RaiseImage)
+        #pragma omp critical (MagickCore_RaiseImage)
 #endif
         proceed=SetImageProgress(image,RaiseImageTag,progress++,image->rows);
         if (proceed == MagickFalse)
